@@ -77,6 +77,7 @@ struct _EphyWebViewPrivate {
   guint is_setting_zoom : 1;
   guint load_failed : 1;
   guint history_frozen : 1;
+  guint ever_committed : 1;
 
   char *address;
   char *typed_address;
@@ -492,9 +493,9 @@ ephy_web_view_create_form_auth_save_confirmation_info_bar (EphyWebView *web_view
 
   LOG ("Going to show infobar about %s", webkit_web_view_get_uri (WEBKIT_WEB_VIEW (web_view)));
 
-  info_bar = gtk_info_bar_new_with_buttons (_("Not now"), GTK_RESPONSE_NO,
-                                            _("Store password"), GTK_RESPONSE_YES,
+  info_bar = gtk_info_bar_new_with_buttons (_("Save"), GTK_RESPONSE_YES,
                                             NULL);
+  gtk_info_bar_set_show_close_button (GTK_INFO_BAR (info_bar), TRUE);
 
   action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
   gtk_orientable_set_orientation (GTK_ORIENTABLE (action_area),
@@ -505,8 +506,8 @@ ephy_web_view_create_form_auth_save_confirmation_info_bar (EphyWebView *web_view
    * hostname where this is happening. Example: gnome@gmail.com and
    * mail.google.com.
    */
-  message = g_markup_printf_escaped (_("<big>Would you like to store the password for <b>%s</b> in <b>%s</b>?</big>"),
-                                     username, hostname);
+  message = g_markup_printf_escaped (_("Do you want to save your password for “%s”?"),
+                                     hostname);
   gtk_label_set_markup (GTK_LABEL (label), message);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   g_free (message);
@@ -1245,6 +1246,22 @@ ephy_web_view_class_init (EphyWebViewClass *klass)
                   G_TYPE_NONE,
                   0);
 
+/**
+ * EphyWebView::donload-only-load:
+ * @view: the #EphyWebView that received the signal
+ *
+ * The ::download-only-load signal is emitted when the @view has its main load
+ * replaced by a download, and that is the only reason why the @view has been created.
+ **/
+    g_signal_new ("download-only-load",
+                  EPHY_TYPE_WEB_VIEW,
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
+
   g_type_class_add_private (gobject_class, sizeof (EphyWebViewPrivate));
 }
 
@@ -1513,6 +1530,8 @@ web_view_check_snapshot (WebKitWebView *web_view)
   GtkTreeIter iter;
   GtkTreeRowReference *ref;
   GtkTreePath *path;
+  EphyWebView* view = EPHY_WEB_VIEW (web_view);
+
   EphyEmbedShell *embed_shell = ephy_embed_shell_get_default ();
 
   store = EPHY_OVERVIEW_STORE (ephy_embed_shell_get_frecent_store (embed_shell));
@@ -1527,6 +1546,8 @@ web_view_check_snapshot (WebKitWebView *web_view)
                                   ref);
   }
 
+  view->priv->snapshot_idle_id = 0;
+
   return FALSE;
 }
 
@@ -1574,6 +1595,8 @@ load_changed_cb (WebKitWebView *web_view,
     const char* uri;
     EphyWebViewSecurityLevel security_level = EPHY_WEB_VIEW_STATE_IS_UNKNOWN;
 
+    priv->ever_committed = TRUE;
+
     /* Title and location. */
     uri = webkit_web_view_get_uri (web_view);
     ephy_web_view_location_changed (view, uri);
@@ -1669,6 +1692,23 @@ ephy_web_view_set_placeholder (EphyWebView *view,
   ephy_web_view_set_address (view, uri);
 }
 
+
+static char *
+get_style_sheet (void)
+{
+  const gchar *file;
+  GError *error = NULL;
+  char *sheet;
+
+  file = ephy_file ("error.css");
+  if (file && !g_file_get_contents (file, &sheet, NULL, &error)) {
+    g_debug ("Unable to load error style sheet: %s", error->message);
+    g_error_free (error);
+  }
+
+  return sheet;
+}
+
 /**
  * ephy_web_view_load_error_page:
  * @view: an #EphyWebView
@@ -1693,10 +1733,8 @@ ephy_web_view_load_error_page (EphyWebView *view,
   char *msg_title;
   char *msg;
   char *button_label;
+  char *stylesheet;
   GBytes *html_file;
-  const char *stock_icon;
-  GtkIconInfo *icon_info;
-  char *image_data;
 
   if (error)
     reason = error->message;
@@ -1710,49 +1748,43 @@ ephy_web_view_load_error_page (EphyWebView *view,
 
   switch (page) {
     case EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR:
-      page_title = g_strdup_printf (_("Oops! Error loading %s"), hostname);
+      page_title = g_strdup_printf (_("Problem loading “%s”"), hostname);
 
-      msg_title = g_strdup (_("Oops! It was not possible to show this website"));
-      msg = g_strdup_printf (_("<p>The website at <strong>%s</strong> seems "
+      msg_title = g_strdup (_("Oops! Unable to display this website."));
+      msg = g_strdup_printf (_("<p>The site at “%s” seems "
                                "to be unavailable. The precise error was:</p>"
-                               "<p><em>%s</em></p>"
-                               "<p>It could be "
-                               "temporarily switched off or moved to a new "
-                               "address. Don't forget to check that your "
+                               "<p><code>%s</code></p>"
+                               "<p>It may be "
+                               "temporarily unavailable or moved to a new "
+                               "address. You may wish to verify that your "
                                "internet connection is working correctly.</p>"),
                              uri, reason);
 
-      button_label = g_strdup (_("Try again"));
+      button_label = g_strdup (_("Try Again"));
 
       html_file = g_resources_lookup_data (EPHY_PAGE_TEMPLATE_ERROR, 0, NULL);
-      stock_icon = "dialog-error";
       break;
     case EPHY_WEB_VIEW_ERROR_PAGE_CRASH:
-      page_title = g_strdup_printf (_("Oops! Error loading %s"), hostname);
+      page_title = g_strdup_printf (_("Problem loading “%s”"), hostname);
 
-      msg_title = g_strdup (_("Oops! This site might have caused the web "
-                              "browser to close unexpectedly"));
-      msg = g_strdup_printf (_("<p>This page was loading when the web browser "
-                               "closed unexpectedly.</p>"
-                               "<p>This might happen again if you "
-                               "reload the page. If it does, "
+      msg_title = g_strdup (_("Oops! There may be a problem."));
+      msg = g_strdup_printf (_("<p>This site may have caused Web to close unexpectedly.</p>"
+                               "<p>If this happens again, "
                                "please report the problem to the "
                                "<strong>%s</strong> developers.</p>"),
                              LSB_DISTRIBUTOR);
 
-      button_label = g_strdup (_("Load again anyway"));
+      button_label = g_strdup (_("Reload Anyway"));
 
       html_file = g_resources_lookup_data (EPHY_PAGE_TEMPLATE_RECOVERY, 0, NULL);
-      stock_icon = "dialog-information";
       break;
     case EPHY_WEB_VIEW_ERROR_PROCESS_CRASH:
-      page_title = g_strdup_printf (_("Oops! Something went wrong displaying %s"), hostname);
+      page_title = g_strdup_printf (_("Problem displaying “%s”"), hostname);
       msg_title = g_strdup (_("Oops!"));
       msg = g_strdup (_("Something went wrong while displaying this page. Please reload or visit a different page to continue."));
       button_label = NULL;
 
       html_file = g_resources_lookup_data (EPHY_PAGE_TEMPLATE_PROCESS_CRASH, 0, NULL);
-      stock_icon = "computer-fail-symbolic";
 
       break;
     default:
@@ -1761,36 +1793,27 @@ ephy_web_view_load_error_page (EphyWebView *view,
   }
   g_free (hostname);
 
-  icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                          stock_icon,
-                                          48,
-                                          GTK_ICON_LOOKUP_GENERIC_FALLBACK);
-
-  image_data = icon_info ? ephy_file_create_data_uri_for_filename (gtk_icon_info_get_filename (icon_info), NULL) : NULL;
-
   ephy_web_view_set_title (view, page_title);
 
   _ephy_web_view_update_icon (view);
 
+  stylesheet = get_style_sheet ();
   g_string_printf (html,
                    g_bytes_get_data (html_file, NULL),
                    lang, lang,
                    ((gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) ? "rtl" : "ltr"),
                    page_title,
+                   stylesheet,
                    uri,
-                   image_data ? image_data : "",
                    msg_title, msg, button_label);
 
   g_bytes_unref (html_file);
+  g_free (stylesheet);
   g_free (lang);
   g_free (page_title);
   g_free (msg_title);
   g_free (msg);
   g_free (button_label);
-  g_free (image_data);
-
-  if (icon_info)
-    g_object_unref (icon_info);
 
   /* Make our history backend ignore the next page load, since it will be an error page. */
   ephy_web_view_freeze_history (view);
@@ -1806,8 +1829,9 @@ load_failed_cb (WebKitWebView *web_view,
                 gpointer user_data)
 {
   EphyWebView *view = EPHY_WEB_VIEW (web_view);
+  EphyWebViewPrivate *priv = view->priv;
 
-  view->priv->load_failed = TRUE;
+  priv->load_failed = TRUE;
   ephy_web_view_set_link_message (view, NULL);
   update_navigation_flags (view);
 
@@ -1838,8 +1862,6 @@ load_failed_cb (WebKitWebView *web_view,
     return TRUE;
   case WEBKIT_NETWORK_ERROR_CANCELLED:
     {
-      EphyWebViewPrivate *priv = view->priv;
-
       if (!priv->typed_address) {
         const char* prev_uri;
 
@@ -1848,10 +1870,15 @@ load_failed_cb (WebKitWebView *web_view,
       }
     }
     break;
-  /* In case we are downloading something or the resource is going to
-   * be showed with a plugin just let WebKit do it */
-  case WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD:
   case WEBKIT_POLICY_ERROR_FRAME_LOAD_INTERRUPTED_BY_POLICY_CHANGE:
+    /* If we are going to download something, and this is the first
+     * page to load in this tab, we may want to close it down. */
+    if (!priv->ever_committed)
+      g_signal_emit_by_name (view, "download-only-load", NULL);
+    break;
+  /* In case the resource is going to be showed with a plugin just let
+   * WebKit do it */
+  case WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD:
   default:
     break;
   }
@@ -1906,6 +1933,7 @@ ephy_web_view_init (EphyWebView *web_view)
   priv = web_view->priv = EPHY_WEB_VIEW_GET_PRIVATE (web_view);
 
   priv->is_blank = TRUE;
+  priv->ever_committed = FALSE;
   priv->title = g_strdup (EMPTY_PAGE);
   priv->document_type = EPHY_WEB_VIEW_DOCUMENT_HTML;
   priv->security_level = EPHY_WEB_VIEW_STATE_IS_UNKNOWN;
@@ -2545,7 +2573,6 @@ ephy_web_view_set_typed_address (EphyWebView *view,
   g_object_notify (G_OBJECT (view), "typed-address");
 }
 
-#ifdef HAVE_WEBKIT2
 static void
 has_modified_forms_cb (GDBusProxy *web_extension,
                        GAsyncResult *result,
@@ -2563,7 +2590,6 @@ has_modified_forms_cb (GDBusProxy *web_extension,
   g_task_return_boolean (task, retval);
   g_object_unref (task);
 }
-#endif
 
 /**
  * ephy_web_view_has_modified_forms:
@@ -2586,7 +2612,6 @@ ephy_web_view_has_modified_forms (EphyWebView *view,
                                   gpointer user_data)
 {
   GTask *task = g_task_new (view, cancellable, callback, user_data);
-#ifdef HAVE_WEBKIT2
   GDBusProxy *web_extension;
 
   web_extension = ephy_embed_shell_get_web_extension_proxy (ephy_embed_shell_get_default ());
@@ -2602,11 +2627,6 @@ ephy_web_view_has_modified_forms (EphyWebView *view,
   } else {
     g_task_return_boolean (task, FALSE);
   }
-#else
-  WebKitDOMDocument *document = webkit_web_view_get_dom_document (WEBKIT_WEB_VIEW (view));
-
-  g_task_return_boolean (task, ephy_web_dom_utils_has_modified_forms (document));
-#endif
 
   g_object_unref (task);
 }
