@@ -35,11 +35,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <string.h>
-#ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
-#else
-#include <webkit/webkit.h>
-#endif
 
 /**
  * SECTION:ephy-location-entry
@@ -83,6 +79,9 @@ struct _EphyLocationEntryPrivate
 	guint needs_reset : 1;
 	guint show_lock : 1;
 	guint show_favicon : 1;
+
+	GtkTargetList *drag_targets;
+	GdkDragAction drag_actions;
 };
 
 static const GtkTargetEntry url_drag_types [] =
@@ -188,6 +187,11 @@ ephy_location_entry_finalize (GObject *object)
 	
 	g_free (priv->saved_text);
 
+	if (priv->drag_targets != NULL)
+	{
+		gtk_target_list_unref (priv->drag_targets);
+	}
+
 	if (priv->favicon != NULL)
 	{
 		g_object_unref (priv->favicon);
@@ -201,14 +205,28 @@ ephy_location_entry_finalize (GObject *object)
 	G_OBJECT_CLASS (ephy_location_entry_parent_class)->finalize (object);
 }
 
+static void
+ephy_location_entry_get_preferred_width (GtkWidget       *widget,
+					 gint            *minimum_width,
+					 gint            *natural_width)
+{
+	if (minimum_width)
+		*minimum_width = -1;
+
+	if (natural_width)
+		*natural_width = 518;
+}
+
 static void
 ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	object_class->get_property = ephy_location_entry_get_property;
 	object_class->set_property = ephy_location_entry_set_property;
 	object_class->finalize = ephy_location_entry_finalize;
+	widget_class->get_preferred_width = ephy_location_entry_get_preferred_width;
 
 	/**
 	* EphyLocationEntry:location:
@@ -376,13 +394,20 @@ update_favicon (EphyLocationEntry *lentry)
 	}
 	else if (priv->show_favicon)
 	{
+		const char *icon_name;
+
 		/* Here we could consider using fallback favicon that matches
 		 * the page MIME type, though text/html should be good enough
 		 * most of the time. See #337140
 		 */
+		if (gtk_entry_get_text_length (entry) > 0)
+			icon_name = "text-x-generic-symbolic";
+		else
+			icon_name = "edit-find-symbolic";
+
 		gtk_entry_set_icon_from_icon_name (entry,
 						   GTK_ENTRY_ICON_PRIMARY,
-						   "text-html");
+						   icon_name);
 	}
 	else
 	{
@@ -855,29 +880,29 @@ static void
 ephy_location_entry_construct_contents (EphyLocationEntry *lentry)
 {
 	GtkWidget *entry = GTK_WIDGET (lentry);
-	GtkTargetList *targetlist;
+	EphyLocationEntryPrivate *priv = lentry->priv;
 
 	LOG ("EphyLocationEntry constructing contents %p", lentry);
 
 	/* Favicon */
-	targetlist = gtk_target_list_new (url_drag_types,
-					  G_N_ELEMENTS (url_drag_types));
+	priv->drag_targets = gtk_target_list_new (url_drag_types,
+						  G_N_ELEMENTS (url_drag_types));
+	priv->drag_actions = GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK;
+
 	gtk_entry_set_icon_drag_source (GTK_ENTRY (entry),
 					GTK_ENTRY_ICON_PRIMARY,
-					targetlist,
-					GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK);
-	gtk_target_list_unref (targetlist);
+					priv->drag_targets,
+					priv->drag_actions);
 
 	gtk_entry_set_icon_tooltip_text (GTK_ENTRY (entry),
 					 GTK_ENTRY_ICON_PRIMARY,
 					 _("Drag and drop this icon to create a link to this page"));
 
-	gtk_entry_set_icon_activatable (GTK_ENTRY (entry),
-					GTK_ENTRY_ICON_PRIMARY,
-					TRUE);
-	gtk_entry_set_icon_activatable (GTK_ENTRY (entry),
-					GTK_ENTRY_ICON_SECONDARY,
-					TRUE);
+	gtk_drag_dest_set (entry,
+			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
+			   url_drag_types,
+			   G_N_ELEMENTS (url_drag_types),
+			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
 	g_object_connect (entry,
 			  "signal::icon-press", G_CALLBACK (icon_button_press_event_cb), lentry,
@@ -888,7 +913,7 @@ ephy_location_entry_construct_contents (EphyLocationEntry *lentry)
 			  "signal::drag-drop", G_CALLBACK (entry_drag_drop_cb), lentry,
 			  "signal::drag-data-get", G_CALLBACK (favicon_drag_data_get_cb), lentry,
 			  NULL);
-			  
+
 	g_signal_connect_after (entry, "key-press-event",
 				G_CALLBACK (entry_key_press_after_cb), lentry);
 	g_signal_connect_after (entry, "activate",
@@ -939,17 +964,10 @@ free_prefetch_helper (PrefetchHelper *helper)
 static gboolean
 do_dns_prefetch (PrefetchHelper *helper)
 {
-#ifdef HAVE_WEBKIT2
 	WebKitWebContext *context = webkit_web_context_get_default ();
 
 	if (helper->uri)
 		webkit_web_context_prefetch_dns (context, helper->uri->host);
-#else
-	SoupSession *session = webkit_get_default_session ();
-
-	if (helper->uri)
-		soup_session_prefetch_dns (session, helper->uri->host, NULL, NULL, NULL);
-#endif
 
 	helper->entry->priv->dns_prefetch_handler = 0;
 
@@ -979,6 +997,7 @@ schedule_dns_prefetch (EphyLocationEntry *entry, guint interval, const gchar *ur
 		g_timeout_add_full (G_PRIORITY_DEFAULT, interval,
 				    (GSourceFunc) do_dns_prefetch, helper,
 				    (GDestroyNotify) free_prefetch_helper);
+	g_source_set_name_by_id (entry->priv->dns_prefetch_handler, "[epiphany] do_dns_prefetch");
 }
 
 static gboolean
@@ -1324,10 +1343,18 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 			effective_text = g_strdup_printf ("about:%s",
 							  address + strlen (EPHY_ABOUT_SCHEME) + 1);
 		text = address;
+		gtk_entry_set_icon_drag_source (GTK_ENTRY (entry),
+						GTK_ENTRY_ICON_PRIMARY,
+						priv->drag_targets,
+						priv->drag_actions);
 	}
 	else
 	{
 		text = "";
+		gtk_entry_set_icon_drag_source (GTK_ENTRY (entry),
+						GTK_ENTRY_ICON_PRIMARY,
+						NULL,
+						GDK_ACTION_DEFAULT);
 	}
 
 	/* First record the new hash, then update the entry text */
