@@ -248,7 +248,8 @@ on_snapshot_saved_cb (EphySnapshotService *service,
 void
 ephy_overview_store_set_snapshot (EphyOverviewStore *store,
                                   GtkTreeIter *iter,
-                                  cairo_surface_t *snapshot)
+                                  cairo_surface_t *snapshot,
+                                  cairo_surface_t *favicon)
 {
   GdkPixbuf *pixbuf;
   char *url;
@@ -257,7 +258,7 @@ ephy_overview_store_set_snapshot (EphyOverviewStore *store,
   int mtime;
 
   mtime = time (NULL);
-  pixbuf = ephy_snapshot_service_crop_snapshot (snapshot);
+  pixbuf = ephy_snapshot_service_prepare_snapshot (snapshot, favicon);
   ephy_overview_store_set_snapshot_internal (store, iter, pixbuf, mtime);
   gtk_tree_model_get (GTK_TREE_MODEL (store), iter,
                       EPHY_OVERVIEW_STORE_URI, &url,
@@ -605,6 +606,7 @@ ephy_overview_store_animated_remove (EphyOverviewStore *store,
   GtkTreePath *path;
   GtkTreeIter iter;
   AnimRemoveContext *ctx = g_slice_new0 (AnimRemoveContext);
+  guint id;
 
   ctx->ref = ref;
   ctx->callback = callback;
@@ -618,7 +620,8 @@ ephy_overview_store_animated_remove (EphyOverviewStore *store,
                       EPHY_OVERVIEW_STORE_CLOSE_BUTTON_RENDER_POLICY,
                       EPHY_REMOVABLE_PIXBUF_RENDER_NEVER, -1);
 
-  g_timeout_add (40, (GSourceFunc) animated_remove_func, ctx);
+  id = g_timeout_add (40, (GSourceFunc) animated_remove_func, ctx);
+  g_source_set_name_by_id (id, "[epiphany] animated_remove_func");
 }
 
 gboolean
