@@ -23,11 +23,18 @@
 
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
+#include "ephy-favicon-helpers.h"
 #include "ephy-history-service.h"
 #include "ephy-shell.h"
 
 #include <string.h>
 
+enum {
+  PROP_0,
+  PROP_HISTORY_SERVICE,
+  PROP_BOOKMARKS
+};
+
 G_DEFINE_TYPE (EphyCompletionModel, ephy_completion_model, GTK_TYPE_LIST_STORE)
 
 #define EPHY_COMPLETION_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_COMPLETION_MODEL, EphyCompletionModelPrivate))
@@ -63,6 +70,24 @@ free_search_terms (GSList *search_terms)
   g_slist_free (search_terms);
 }
 
+static void
+ephy_completion_model_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec)
+{
+  EphyCompletionModel *self = EPHY_COMPLETION_MODEL (object);
+
+  switch (property_id) {
+  case PROP_HISTORY_SERVICE:
+    self->priv->history_service = EPHY_HISTORY_SERVICE (g_value_get_pointer (value));
+    break;
+  case PROP_BOOKMARKS:
+    self->priv->bookmarks = ephy_bookmarks_get_bookmarks (EPHY_BOOKMARKS (g_value_get_pointer (value)));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (self, property_id, pspec);
+    break;
+  }
+}
+
 static void
 ephy_completion_model_finalize (GObject *object)
 {
@@ -86,24 +111,30 @@ ephy_completion_model_class_init (EphyCompletionModelClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+  object_class->set_property = ephy_completion_model_set_property;
   object_class->constructed = ephy_completion_model_constructed;
   object_class->finalize = ephy_completion_model_finalize;
 
+  g_object_class_install_property (object_class,
+                                   PROP_HISTORY_SERVICE,
+                                   g_param_spec_pointer ("history-service",
+                                                         "History Service",
+                                                         "The history service",
+                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+  g_object_class_install_property (object_class,
+                                   PROP_BOOKMARKS,
+                                   g_param_spec_pointer ("bookmarks",
+                                                         "Bookmarks",
+                                                         "The bookmarks",
+                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+
   g_type_class_add_private (object_class, sizeof (EphyCompletionModelPrivate));
 }
 
 static void
 ephy_completion_model_init (EphyCompletionModel *model)
 {
-  EphyCompletionModelPrivate *priv;
-  EphyBookmarks *bookmarks_service;
-
-  model->priv = priv = EPHY_COMPLETION_MODEL_GET_PRIVATE (model);
-
-  priv->history_service = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (embed_shell));
-
-  bookmarks_service = ephy_shell_get_bookmarks (ephy_shell);
-  priv->bookmarks = ephy_bookmarks_get_bookmarks (bookmarks_service);
+  model->priv = EPHY_COMPLETION_MODEL_GET_PRIVATE (model);
 }
 
 static gboolean
@@ -166,22 +197,25 @@ typedef struct {
   gboolean is_bookmark;
 } PotentialRow;
 
-#ifdef HAVE_WEBKIT2
-/* TODO: Favicons */
-#else
 typedef struct {
   GtkListStore *model;
   GtkTreeRowReference *row_reference;
 } IconLoadData;
 
-
 static void
 icon_loaded_cb (GObject *source, GAsyncResult *result, gpointer user_data)
 {
   GtkTreeIter iter;
   GtkTreePath *path;
   IconLoadData *data = (IconLoadData *) user_data;
-  GdkPixbuf *favicon = webkit_favicon_database_get_favicon_pixbuf_finish (webkit_get_favicon_database (), result, NULL);
+  WebKitFaviconDatabase *database = WEBKIT_FAVICON_DATABASE (source);
+  GdkPixbuf *favicon = NULL;
+  cairo_surface_t *icon_surface = webkit_favicon_database_get_favicon_finish (database, result, NULL);
+
+  if (icon_surface) {
+    favicon = ephy_pixbuf_get_from_surface_scaled (icon_surface, FAVICON_SIZE, FAVICON_SIZE);
+    cairo_surface_destroy (icon_surface);
+  }
 
   if (favicon) {
     /* The completion model might have changed its contents */
@@ -198,20 +232,16 @@ icon_loaded_cb (GObject *source, GAsyncResult *result, gpointer user_data)
   gtk_tree_row_reference_free (data->row_reference);
   g_slice_free (IconLoadData, data);
 }
-#endif
 
 static void
 set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
 {
   GtkTreeIter iter;
-  GdkPixbuf *favicon;
   GtkTreePath *path;
-#ifdef HAVE_WEBKIT2
-  /* TODO: Favicons */
-#else
   IconLoadData *data;
-  WebKitFaviconDatabase* database = webkit_get_favicon_database ();
-#endif
+  WebKitFaviconDatabase* database;
+
+  database = webkit_web_context_get_favicon_database (webkit_web_context_get_default ());
 
   gtk_list_store_insert_with_values (GTK_LIST_STORE (model), &iter, position,
                                      EPHY_COMPLETION_TEXT_COL, row->title ? row->title : "",
@@ -222,29 +252,14 @@ set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
                                      EPHY_COMPLETION_RELEVANCE_COL, row->relevance,
                                      -1);
 
-#ifdef HAVE_WEBKIT2
-  /* TODO: Favicons */
-#else
-  /* We try first with the try_get_favicon_pixbuf() because if the icon
-     is in the DB it's faster than the async version. */
-  favicon = webkit_favicon_database_try_get_favicon_pixbuf (database, row->location,
-                                                            FAVICON_SIZE, FAVICON_SIZE);
-  if (favicon) {
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter, EPHY_COMPLETION_FAVICON_COL, favicon, -1);
-    g_object_unref (favicon);
-    return;
-  }
-
   data = g_slice_new (IconLoadData);
   data->model = GTK_LIST_STORE (g_object_ref(model));
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
   data->row_reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
   gtk_tree_path_free (path);
 
-  webkit_favicon_database_get_favicon_pixbuf (database, row->location,
-                                              FAVICON_SIZE, FAVICON_SIZE, NULL,
-                                              icon_loaded_cb, data);
-#endif
+  webkit_favicon_database_get_favicon (database, row->location,
+                                       NULL, icon_loaded_cb, data);
 }
 
 static void
@@ -568,7 +583,14 @@ ephy_completion_model_update_for_string (EphyCompletionModel *model,
 }
 
 EphyCompletionModel *
-ephy_completion_model_new (void)
+ephy_completion_model_new (EphyHistoryService *history_service,
+                           EphyBookmarks      *bookmarks)
 {
-  return g_object_new (EPHY_TYPE_COMPLETION_MODEL, NULL);
+  g_return_val_if_fail (EPHY_IS_HISTORY_SERVICE (history_service), NULL);
+  g_return_val_if_fail (EPHY_IS_BOOKMARKS (bookmarks), NULL);
+
+  return g_object_new (EPHY_TYPE_COMPLETION_MODEL,
+                       "history-service", history_service,
+                       "bookmarks", bookmarks,
+                       NULL);
 }
