@@ -27,6 +27,7 @@
 #include "ephy-embed-container.h"
 #include "ephy-embed-utils.h"
 #include "ephy-link.h"
+#include "ephy-dnd.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
 
@@ -135,6 +136,53 @@ action_activated_cb (GtkEntryCompletion *completion,
 	}
 }
 
+static void
+entry_drag_data_received_cb (GtkWidget *widget,
+			     GdkDragContext *context,
+			     gint x, gint y,
+			     GtkSelectionData *selection_data,
+			     guint info,
+			     guint time,
+			     EphyLocationController *controller)
+{
+	GtkEntry *entry;
+	GdkAtom url_type;
+	GdkAtom text_type;
+	const guchar *sel_data;
+
+	sel_data = gtk_selection_data_get_data (selection_data);
+
+	url_type = gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE);
+	text_type = gdk_atom_intern (EPHY_DND_TEXT_TYPE, FALSE);
+
+	if (gtk_selection_data_get_length (selection_data) <= 0 || sel_data == NULL)
+		return;
+
+	entry = GTK_ENTRY (widget);
+
+	if (gtk_selection_data_get_target (selection_data) == url_type)
+	{
+		char **uris;
+
+		uris = g_uri_list_extract_uris ((char *)sel_data);
+		if (uris != NULL && uris[0] != NULL && *uris[0] != '\0')
+		{
+			gtk_entry_set_text (entry, (char *)uris[0]);
+			ephy_link_open (EPHY_LINK (controller),
+					uris[0],
+					NULL,
+					ephy_link_flags_from_current_event ());
+		}
+		g_strfreev (uris);
+	} else if (gtk_selection_data_get_target (selection_data) == text_type) {
+		gtk_entry_set_text (entry, (const gchar *)sel_data);
+		ephy_link_open (EPHY_LINK (controller),
+				(const gchar *)sel_data,
+				NULL,
+				ephy_link_flags_from_current_event ());
+	}
+}
+
 static void
 entry_activate_cb (GtkEntry *entry,
 		   EphyLocationController *controller)
@@ -342,6 +390,8 @@ ephy_location_controller_constructed (GObject *object)
 {
 	EphyLocationController *controller = EPHY_LOCATION_CONTROLLER (object);
 	EphyLocationControllerPrivate *priv = controller->priv;
+	EphyHistoryService *history_service;
+	EphyBookmarks *bookmarks;
 	EphyCompletionModel *model;
 	GtkWidget *notebook, *widget;
 
@@ -353,7 +403,9 @@ ephy_location_controller_constructed (GObject *object)
 	g_signal_connect (notebook, "switch-page",
 			  G_CALLBACK (switch_page_cb), controller);
 
-	model = ephy_completion_model_new ();
+	history_service = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ()));
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+	model = ephy_completion_model_new (history_service, bookmarks);
 	ephy_location_entry_set_completion (priv->location_entry,
 					    GTK_TREE_MODEL (model),
 					    EPHY_COMPLETION_TEXT_COL,
@@ -395,6 +447,9 @@ ephy_location_controller_constructed (GObject *object)
 				priv->location_entry, "show-lock",
 				G_BINDING_SYNC_CREATE);
 
+	g_signal_connect_object (widget, "drag-data-received",
+				 G_CALLBACK (entry_drag_data_received_cb),
+				 controller, 0);
 	g_signal_connect_object (widget, "activate",
 				 G_CALLBACK (entry_activate_cb),
 				 controller, 0);
@@ -757,7 +812,7 @@ ephy_location_controller_init (EphyLocationController *controller)
 
 	priv->address = g_strdup ("");
 	priv->editable = TRUE;
-	priv->bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	priv->bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
 	priv->smart_bmks = ephy_bookmarks_get_smart_bookmarks
 		(controller->priv->bookmarks);
 	priv->sync_address_is_blocked = FALSE;
