@@ -35,17 +35,16 @@
 #include "ephy-lockdown.h"
 #include "ephy-prefs.h"
 #include "ephy-private.h"
-#include "ephy-search-provider.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-type-builtins.h"
 #include "ephy-web-view.h"
 #include "ephy-window.h"
-#include "pdm-dialog.h"
 #include "prefs-dialog.h"
 #include "window-commands.h"
 
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
@@ -54,7 +53,6 @@
 #define EPHY_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SHELL, EphyShellPrivate))
 
 struct _EphyShellPrivate {
-  EphySearchProvider *search_provider;
   EphySession *session;
   GList *windows;
   GObject *lockdown;
@@ -62,7 +60,6 @@ struct _EphyShellPrivate {
   GNetworkMonitor *network_monitor;
   GtkWidget *bme;
   GtkWidget *history_window;
-  GObject *pdm_dialog;
   GObject *prefs_dialog;
   GList *del_on_exit;
   EphyShellStartupContext *startup_context;
@@ -139,7 +136,8 @@ ephy_shell_startup_continue (EphyShell *shell)
    * otherwise our first call to ephy_window_is_on_current_workspace
    * will be unreliable.
    */
-  wnck_screen_force_update (wnck_screen_get_default ());
+  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+    wnck_screen_force_update (wnck_screen_get_default ());
 }
 
 static void
@@ -187,15 +185,11 @@ show_preferences (GSimpleAction *action,
                   GVariant *parameter,
                   gpointer user_data)
 {
-  window_cmd_edit_preferences (NULL, NULL);
-}
+  GtkWindow *window;
 
-static void
-show_pdm (GSimpleAction *action,
-          GVariant *parameter,
-          gpointer user_data)
-{
-  window_cmd_edit_personal_data (NULL, NULL);
+  window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
+
+  window_cmd_edit_preferences (NULL, EPHY_WINDOW (window));
 }
 
 static void
@@ -236,7 +230,6 @@ static GActionEntry app_entries[] = {
   { "bookmarks", show_bookmarks, NULL, NULL, NULL },
   { "history", show_history, NULL, NULL, NULL },
   { "preferences", show_preferences, NULL, NULL, NULL },
-  { "pdm", show_pdm, NULL, NULL, NULL },
   { "help", show_help, NULL, NULL, NULL },
   { "about", show_about, NULL, NULL, NULL },
   { "quit", quit_application, NULL, NULL, NULL },
@@ -297,20 +290,6 @@ session_load_cb (GObject *object,
   ephy_shell_startup_continue (shell);
 }
 
-static void
-ephy_shell_start_headless (EphyShell *shell)
-{
-  /* A bit of a hack: because we don't pass IS_SERVICE to GApplication
-     (because otherwise we would need a separate launcher binary), we
-     don't get the 10 seconds timeout for the first DBus call.
-     So just hold/release to get the inactivity timeout started instead.
-  */
-
-  g_application_hold (G_APPLICATION (shell));
-  g_application_release (G_APPLICATION (shell));
-  ephy_shell_startup_continue (shell);
-}
-
 static void
 ephy_shell_activate (GApplication *application)
 {
@@ -318,18 +297,14 @@ ephy_shell_activate (GApplication *application)
 
   /*
    * We get here on each new instance (remote or not). Autoresume the
-   * session unless we are in application or headless mode and queue the
-   * commands.
+   * session unless we are in application mode and queue the commands.
    */
   if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) != EPHY_EMBED_SHELL_MODE_APPLICATION) {
     EphyShellStartupContext *ctx;
 
     ctx = shell->priv->startup_context;
-    if (ctx->startup_flags != EPHY_STARTUP_OPEN_NOTHING)
-      ephy_session_resume (ephy_shell_get_session (shell),
-                           ctx->user_time, NULL, session_load_cb, shell);
-    else
-      ephy_shell_start_headless (shell);
+    ephy_session_resume (ephy_shell_get_session (shell),
+                         ctx->user_time, NULL, session_load_cb, shell);
   } else
     ephy_shell_startup_continue (shell);
 }
@@ -521,42 +496,6 @@ ephy_shell_constructed (GObject *object)
     G_OBJECT_CLASS (ephy_shell_parent_class)->constructed (object);
 }
 
-static gboolean
-ephy_shell_dbus_register (GApplication    *application,
-                          GDBusConnection *connection,
-                          const gchar     *object_path,
-                          GError         **error)
-{
-  EphyShell *self;
-
-  if (!G_APPLICATION_CLASS (ephy_shell_parent_class)->dbus_register (application,
-                                                                     connection,
-                                                                     object_path,
-                                                                     error))
-    return FALSE;
-
-  self = EPHY_SHELL (application);
-
-  return ephy_search_provider_dbus_register (self->priv->search_provider, connection,
-                                             object_path, error);
-}
-
-static void
-ephy_shell_dbus_unregister (GApplication    *application,
-                            GDBusConnection *connection,
-                            const gchar     *object_path)
-{
-  EphyShell *self;
-
-  self = EPHY_SHELL (application);
-  if (self->priv->search_provider)
-    ephy_search_provider_dbus_unregister (self->priv->search_provider, connection, object_path);
-
-  G_APPLICATION_CLASS (ephy_shell_parent_class)->dbus_unregister (application,
-                                                                  connection,
-                                                                  object_path);
-}
-
 static void
 ephy_shell_class_init (EphyShellClass *klass)
 {
@@ -571,13 +510,10 @@ ephy_shell_class_init (EphyShellClass *klass)
   application_class->activate = ephy_shell_activate;
   application_class->before_emit = ephy_shell_before_emit;
   application_class->add_platform_data = ephy_shell_add_platform_data;
-  application_class->dbus_register = ephy_shell_dbus_register;
-  application_class->dbus_unregister = ephy_shell_dbus_unregister;
 
   g_type_class_add_private (object_class, sizeof(EphyShellPrivate));
 }
 
-#ifdef HAVE_WEBKIT2
 static void
 download_started_cb (WebKitWebContext *web_context,
                      WebKitDownload *download,
@@ -617,18 +553,14 @@ download_started_cb (WebKitWebContext *web_context,
 
   ephy_download_new_for_download (download, window);
 }
-#endif
 
 static void
 ephy_shell_init (EphyShell *shell)
 {
   EphyShell **ptr = &ephy_shell;
-
-#ifdef HAVE_WEBKIT2
   WebKitWebContext *web_context;
   EphyEmbedShellMode mode;
   char *favicon_db_path;
-#endif
 
   shell->priv = EPHY_SHELL_GET_PRIVATE (shell);
 
@@ -638,7 +570,6 @@ ephy_shell_init (EphyShell *shell)
   g_object_add_weak_pointer (G_OBJECT (ephy_shell),
                              (gpointer *)ptr);
 
-#ifdef HAVE_WEBKIT2
   web_context = webkit_web_context_get_default ();
   g_signal_connect (web_context, "download-started",
                     G_CALLBACK (download_started_cb),
@@ -653,11 +584,6 @@ ephy_shell_init (EphyShell *shell)
 
   webkit_web_context_set_favicon_database_directory (web_context, favicon_db_path);
   g_free (favicon_db_path);
-#endif
-
-  shell->priv->search_provider = ephy_search_provider_new ();
-
-  g_application_set_inactivity_timeout (G_APPLICATION (shell), 60 * 1000);
 }
 
 static void
@@ -667,12 +593,10 @@ ephy_shell_dispose (GObject *object)
 
   LOG ("EphyShell disposing");
 
-  g_clear_object (&priv->search_provider);
   g_clear_object (&priv->session);
   g_clear_object (&priv->lockdown);
   g_clear_pointer (&priv->bme, gtk_widget_destroy);
   g_clear_pointer (&priv->history_window, gtk_widget_destroy);
-  g_clear_object (&priv->pdm_dialog);
   g_clear_object (&priv->prefs_dialog);
   g_clear_object (&priv->bookmarks);
   g_clear_object (&priv->network_monitor);
@@ -730,11 +654,7 @@ EphyEmbed *
 ephy_shell_new_tab_full (EphyShell *shell,
                          EphyWindow *parent_window,
                          EphyEmbed *previous_embed,
-#ifdef HAVE_WEBKIT2
                          WebKitURIRequest *request,
-#else
-                         WebKitNetworkRequest *request,
-#endif
                          EphyNewTabFlags flags,
                          EphyWebViewChrome chrome,
                          gboolean is_popup,
@@ -756,11 +676,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
   g_return_val_if_fail (EPHY_IS_SHELL (shell), NULL);
   g_return_val_if_fail (EPHY_IS_WINDOW (parent_window) || !parent_window, NULL);
   g_return_val_if_fail (EPHY_IS_EMBED (previous_embed) || !previous_embed, NULL);
-#ifdef HAVE_WEBKIT2
   g_return_val_if_fail (WEBKIT_IS_URI_REQUEST (request) || !request, NULL);
-#else
-  g_return_val_if_fail (WEBKIT_IS_NETWORK_REQUEST (request) || !request, NULL);
-#endif
 
   embed_shell = EPHY_EMBED_SHELL (shell);
 
@@ -844,11 +760,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
     ephy_web_view_load_request (ephy_embed_get_web_view (embed),
                                 request);
 
-#ifdef HAVE_WEBKIT2
     is_empty = ephy_embed_utils_url_is_empty (webkit_uri_request_get_uri (request));
-#else
-    is_empty = ephy_embed_utils_url_is_empty (webkit_network_request_get_uri (request));
-#endif
   } else if (delayed_open_page)
       ephy_embed_set_delayed_load_request (embed, request);
 
@@ -896,11 +808,7 @@ ephy_shell_new_tab (EphyShell *shell,
                     EphyNewTabFlags flags)
 {
   EphyEmbed *embed;
-#ifdef HAVE_WEBKIT2
   WebKitURIRequest *request = url ? webkit_uri_request_new (url) : NULL;
-#else
-  WebKitNetworkRequest *request = url ? webkit_network_request_new (url) : NULL;
-#endif
 
   embed = ephy_shell_new_tab_full (shell, parent_window,
                                    previous_embed, request, flags,
@@ -1003,28 +911,6 @@ ephy_shell_get_history_window (EphyShell *shell)
   return shell->priv->history_window;
 }
 
-/**
- * ephy_shell_get_pdm_dialog:
- *
- * Return value: (transfer none):
- **/
-GObject *
-ephy_shell_get_pdm_dialog (EphyShell *shell)
-{
-  if (shell->priv->pdm_dialog == NULL) {
-    GObject **dialog;
-
-    shell->priv->pdm_dialog = g_object_new (EPHY_TYPE_PDM_DIALOG, NULL);
-
-    dialog = &shell->priv->pdm_dialog;
-
-    g_object_add_weak_pointer (shell->priv->pdm_dialog,
-                               (gpointer *)dialog);
-  }
-
-  return shell->priv->pdm_dialog;
-}
-
 /**
  * ephy_shell_get_prefs_dialog:
  *
@@ -1034,14 +920,11 @@ GObject *
 ephy_shell_get_prefs_dialog (EphyShell *shell)
 {
   if (shell->priv->prefs_dialog == NULL) {
-    GObject **dialog;
-
     shell->priv->prefs_dialog = g_object_new (EPHY_TYPE_PREFS_DIALOG, NULL);
-
-    dialog  = &shell->priv->prefs_dialog;
-
-    g_object_add_weak_pointer (shell->priv->prefs_dialog,
-                               (gpointer *)dialog);
+    g_signal_connect (shell->priv->prefs_dialog,
+                      "destroy",
+                      G_CALLBACK (gtk_widget_destroyed),
+                      &shell->priv->prefs_dialog);
   }
 
   return shell->priv->prefs_dialog;
@@ -1219,22 +1102,14 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
   EphyEmbed *embed;
   EphyNewTabFlags page_flags;
   const char *url;
-#ifdef HAVE_WEBKIT2
   WebKitURIRequest *request = NULL;
-#else
-  WebKitNetworkRequest *request = NULL;
-#endif
 
   url = data->uris[data->current_uri];
   if (url[0] == '\0') {
     page_flags = EPHY_NEW_TAB_HOME_PAGE;
   } else {
     page_flags = EPHY_NEW_TAB_OPEN_PAGE;
-#ifdef HAVE_WEBKIT2
     request = webkit_uri_request_new (url);
-#else
-    request = webkit_network_request_new (url);
-#endif
   }
 
   embed = ephy_shell_new_tab_full (ephy_shell_get_default (),
