@@ -33,11 +33,7 @@
 #include "ephy-session.h"
 #include "ephy-window.h"
 
-#ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
-#else
-#include <webkit/webkit.h>
-#endif
 #include <glib-object.h>
 #include <glib.h>
 
@@ -113,7 +109,6 @@ typedef enum {
 typedef enum {
   EPHY_STARTUP_NEW_TAB          = 1 << 0,
   EPHY_STARTUP_NEW_WINDOW       = 1 << 1,
-  EPHY_STARTUP_OPEN_NOTHING     = 1 << 2,
 } EphyStartupFlags;
 
 typedef struct {
@@ -154,11 +149,7 @@ EphyEmbed      *ephy_shell_new_tab                      (EphyShell *shell,
 EphyEmbed      *ephy_shell_new_tab_full                 (EphyShell *shell,
                                                          EphyWindow *parent_window,
                                                          EphyEmbed *previous_embed,
-#ifdef HAVE_WEBKIT2
                                                          WebKitURIRequest *request,
-#else
-                                                         WebKitNetworkRequest *request,
-#endif
                                                          EphyNewTabFlags flags,
                                                          EphyWebViewChrome chrome,
                                                          gboolean is_popup,
@@ -174,8 +165,6 @@ GtkWidget       *ephy_shell_get_bookmarks_editor         (EphyShell *shell);
 
 GtkWidget       *ephy_shell_get_history_window           (EphyShell *shell);
 
-GObject         *ephy_shell_get_pdm_dialog               (EphyShell *shell);
-
 GObject         *ephy_shell_get_prefs_dialog             (EphyShell *shell);
 
 guint           ephy_shell_get_n_windows                (EphyShell *shell);
