@@ -36,11 +36,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <string.h>
-#ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
-#else
-#include <webkit/webkit.h>
-#endif
 
 void
 popup_cmd_link_in_new_window (GtkAction *action,
@@ -95,7 +91,6 @@ void
 popup_cmd_bookmark_link (GtkAction *action,
 			 EphyWindow *window)
 {
-#ifdef HAVE_WEBKIT2
 	EphyEmbedEvent *event;
 	WebKitHitTestResult *result;
 	const char *title;
@@ -117,64 +112,6 @@ popup_cmd_bookmark_link (GtkAction *action,
 	}
 
 	ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (window), location, title);
-#else
-	EphyEmbedEvent *event;
-	char *title;
-	char *location = NULL;
-	guint context;
-	WebKitHitTestResult *result;
-	WebKitDOMNode *node, *first_child;
-
-	event = ephy_window_get_context_event (window);
-	g_return_if_fail (event != NULL);
-
-	result = ephy_embed_event_get_hit_test_result (event);
-	g_object_get (result, "context", &context, NULL);
-	g_object_get (result, "inner-node", &node, NULL);
-
-	if (context != WEBKIT_HIT_TEST_RESULT_CONTEXT_LINK)
-	{
-		node = WEBKIT_DOM_NODE (webkit_dom_node_get_parent_element (WEBKIT_DOM_NODE (node)));
-		if (WEBKIT_DOM_IS_HTML_ANCHOR_ELEMENT (node))
-			location = webkit_dom_html_anchor_element_get_href (WEBKIT_DOM_HTML_ANCHOR_ELEMENT (node));
-	}
-	else
-	{
-		g_object_get (result, "link-uri", &location, NULL);
-	}
-
-	if (!node || !location)
-		return;
-
-	title = webkit_dom_html_element_get_title (WEBKIT_DOM_HTML_ELEMENT (node));
-	
-	if (title == NULL || title[0] == '\0')
-	{
-		title = webkit_dom_html_anchor_element_get_text (WEBKIT_DOM_HTML_ANCHOR_ELEMENT (node));
-	}
-
-	/* Sometimes boorkmaklets are presented as images inside a
-	 * link, try that. */
-	if (title == NULL || title[0] == '\0')
-	{
-		first_child = webkit_dom_node_get_first_child (WEBKIT_DOM_NODE (node));
-		if (first_child && WEBKIT_DOM_IS_HTML_IMAGE_ELEMENT (first_child))
-		{
-			title = webkit_dom_html_image_element_get_alt (WEBKIT_DOM_HTML_IMAGE_ELEMENT (first_child));
-			if (title == NULL || title[0] == '\0')
-				title = webkit_dom_html_image_element_get_name (WEBKIT_DOM_HTML_IMAGE_ELEMENT (first_child));
-		}
-	}
-
-	if (title == NULL || title[0] == '\0')
-	{
-		title = location;
-	}
-	
-	ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (window), location, title);
-	g_free (title);
-	g_free (location);
-#endif
 }
 
 static void
@@ -251,6 +188,37 @@ response_cb (GtkDialog *dialog,
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
+static char *
+get_suggested_filename (EphyWebView *view)
+{
+	char *suggested_filename = NULL;
+	const char *mimetype;
+	WebKitURIResponse *response;
+	WebKitWebResource *web_resource;
+
+	web_resource = webkit_web_view_get_main_resource (WEBKIT_WEB_VIEW (view));
+	response = webkit_web_resource_get_response (web_resource);
+	mimetype = webkit_uri_response_get_mime_type (response);
+
+	if ((g_ascii_strncasecmp (mimetype, "text/html", 9)) == 0)
+	{
+		/* Web Title will be used as suggested filename */
+		suggested_filename = g_strconcat (ephy_web_view_get_title (view), ".mhtml", NULL);
+	}
+	else
+	{
+		suggested_filename = g_strdup (webkit_uri_response_get_suggested_filename (response));
+		if (!suggested_filename)
+		{
+			SoupURI *soup_uri = soup_uri_new (webkit_web_resource_get_uri (web_resource));
+			suggested_filename = g_path_get_basename (soup_uri->path);
+			soup_uri_free (soup_uri);
+		}
+	}
+
+	return suggested_filename;
+}
+
 static void
 save_property_url (GtkAction *action,
 		   const char *title,
@@ -271,22 +239,26 @@ save_property_url (GtkAction *action,
 	if (ask_dest)
 	{
 		EphyFileChooser *dialog;
-		char *base;
+		EphyEmbed *embed;
+		EphyWebView *view;
+		char *suggested_filename;
+
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
+		view = ephy_embed_get_web_view (embed);
 
-		base = g_path_get_basename (location);
 		dialog = ephy_file_chooser_new (title, GTK_WIDGET (window),
 						GTK_FILE_CHOOSER_ACTION_SAVE,
 						EPHY_FILE_FILTER_NONE);
 
+		suggested_filename = ephy_sanitize_filename (get_suggested_filename (view));
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), suggested_filename);
+		g_free (suggested_filename);
+
 		gtk_file_chooser_set_do_overwrite_confirmation
 				(GTK_FILE_CHOOSER (dialog), TRUE);
-		gtk_file_chooser_set_current_name
-				(GTK_FILE_CHOOSER (dialog), base);
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (response_cb), g_strdup (location));
 		gtk_widget_show (GTK_WIDGET (dialog));
-
-		g_free (base);
 	}
 	else
 	{
@@ -294,34 +266,6 @@ save_property_url (GtkAction *action,
 	}
 }
 
-void
-popup_cmd_open_link (GtkAction *action,
-		     EphyWindow *window)
-{
-	EphyEmbedEvent *event;
-	const char *location;
-	GValue value = { 0, };
-	EphyEmbed *embed;
-
-	embed = ephy_embed_container_get_active_child 
-		(EPHY_EMBED_CONTAINER (window));
-	g_return_if_fail (embed != NULL);
-
-	event = ephy_window_get_context_event (window);
-	ephy_embed_event_get_property (event, "link-uri", &value);
-	location = g_value_get_string (&value);
-	ephy_web_view_load_url (ephy_embed_get_web_view (embed), location);
-	g_value_unset (&value);
-}
-
-void
-popup_cmd_download_link (GtkAction *action,
-			 EphyWindow *window)
-{
-	save_property_url (action, _("Download Link"), window, 
-			   FALSE, "link-uri");
-}
-
 void
 popup_cmd_download_link_as (GtkAction *action,
 			    EphyWindow *window)
@@ -402,183 +346,28 @@ popup_cmd_copy_image_location (GtkAction *action,
 	g_value_unset (&value);
 }
 
-/* Opens an image URI using its associated handler. Or, if that
- * doesn't work, fallback to open the URI in a new browser window.
- */
-static void
-image_open_uri (GFile *file,
-                const char *remote_address,
-		guint32 user_time)
-{
-	gboolean success;
-
-	success = ephy_file_launch_handler (NULL, file, user_time);
-
-	if (!success)
-	{
-		ephy_shell_new_tab (ephy_shell_get_default (),
-				    NULL, NULL, remote_address,
-				    EPHY_NEW_TAB_OPEN_PAGE |
-				    EPHY_NEW_TAB_IN_NEW_WINDOW);
-	}
-
-	if (strcmp (remote_address, g_file_get_uri (file)) != 0)
-	{
-		if (success)
-			ephy_file_delete_on_exit (file);
-		else
-			g_file_delete (file, NULL, NULL);
-	}
-}
-
-static void
-save_source_completed_cb (EphyDownload *download)
-{
-	const char *dest;
-	const char *source;
-	guint32 user_time;
-	GFile *file;
-
-	user_time = ephy_download_get_start_time (download);
-	dest = ephy_download_get_destination_uri (download);
-	source = ephy_download_get_source_uri (download);
-	g_return_if_fail (dest != NULL);
-	
-	file = g_file_new_for_uri (dest);
-
-	image_open_uri (file, source, user_time);
-	g_object_unref (file);
-}
-
-static void
-save_temp_source (const char *address)
-{
-	EphyDownload *download;
-	const char *static_temp_dir;
-	char *base, *tmp_name, *tmp_path, *dest, *dest_uri;
-
-	if (address == NULL) return;
-
-	static_temp_dir = ephy_file_tmp_dir ();
-	if (static_temp_dir == NULL) return;
-
-	base = g_path_get_basename (address);
-	tmp_name = g_strconcat (base, ".XXXXXX", NULL);
-	g_free (base);
-
-	tmp_path = g_build_filename (static_temp_dir, tmp_name, NULL);
-	g_free (tmp_name);
-
-	dest = ephy_file_tmp_filename (tmp_path, NULL);
-	g_free (tmp_path);
-
-	if (dest == NULL) return;
-
-	dest_uri = g_filename_to_uri (dest, NULL, NULL);
-	download = ephy_download_new_for_uri (address, NULL);
-	ephy_download_set_destination_uri (download, dest_uri);
-
-	g_signal_connect (download, "completed",
-			  G_CALLBACK (save_source_completed_cb), NULL);
-
-	ephy_download_start (download);
-
-	g_free (dest);
-	g_free (dest_uri);
-}
-
 void
-popup_replace_spelling (GtkAction *action,
-			EphyWindow *window)
-{
-#ifdef HAVE_WEBKIT2
-	/* TODO: Context Menu, Spellchecker */
-#else
-	EphyEmbed *embed;
-	WebKitWebView *view;
-	WebKitWebFrame *frame;
-	WebKitDOMDOMSelection *selection;
-	WebKitDOMDocument *document;
-	WebKitDOMDOMWindow *default_view;
-
-	embed = ephy_embed_container_get_active_child 
-		(EPHY_EMBED_CONTAINER (window));
-	g_return_if_fail (embed != NULL);
-
-	view = WEBKIT_WEB_VIEW (ephy_embed_get_web_view (embed));
-	g_return_if_fail (view != NULL);
-
-	document = webkit_web_view_get_dom_document (view);
-	default_view = webkit_dom_document_get_default_view (document);
-	selection = webkit_dom_dom_window_get_selection (default_view);
-	webkit_dom_dom_selection_modify (selection, "move", "backward", "word");
-	webkit_dom_dom_selection_modify (selection, "extend", "forward", "word");
-	frame = webkit_web_view_get_focused_frame (view);
-	webkit_web_frame_replace_selection (frame, gtk_action_get_label (action));
-#endif
-}
-
-void
-popup_cmd_open_image (GtkAction *action,
-		      EphyWindow *window)
+popup_cmd_view_image_in_new_tab (GtkAction *action,
+				 EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	const char *address;
-	char *scheme = NULL;
 	GValue value = { 0, };
 	EphyEmbed *embed;
 
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_embed_container_get_active_child 
-		(EPHY_EMBED_CONTAINER (window));
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	ephy_embed_event_get_property (event, "image-uri", &value);
-	address = g_value_get_string (&value);
 
-	scheme = g_uri_parse_scheme (address);
-	if (scheme == NULL) goto out;
-
-	if (strcmp (scheme, "file") == 0)
-	{
-		GFile *file;
-		
-		file = g_file_new_for_uri (address);
-		image_open_uri (file, address,
-				gtk_get_current_event_time ());
-		g_object_unref (file);
-	}
-	else
-	{
-		save_temp_source (address);
-	}
-
- out:
+	ephy_shell_new_tab (ephy_shell_get_default (),
+			    window, embed,
+			    g_value_get_string (&value),
+			    EPHY_NEW_TAB_OPEN_PAGE |
+			    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
+			    EPHY_NEW_TAB_APPEND_AFTER);
 	g_value_unset (&value);
-	g_free (scheme);
 }
 
-void
-popup_cmd_inspect_element (GtkAction *action, EphyWindow *window)
-{
-#ifndef HAVE_WEBKIT2
-	EphyEmbedEvent *event;
-	EphyEmbed *embed;
-	WebKitWebInspector *inspector;
-	guint x, y;
-
-	embed = ephy_embed_container_get_active_child
-		(EPHY_EMBED_CONTAINER (window));
-
-	event = ephy_window_get_context_event (window);
-	g_return_if_fail (event != NULL);
-
-	inspector = webkit_web_view_get_inspector
-		(EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
-
-	ephy_embed_event_get_coords (event, &x, &y);
-	webkit_web_inspector_inspect_coordinates (inspector, (gdouble)x, (gdouble)y);
-#endif
-}
